#
# spec file for package git-review
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-review
Version:        2.3.1
Release:        2.2
Summary:        Tool to submit code to Gerrit
License:        Apache-2.0
URL:            https://git.openstack.org/cgit/openstack-infra/git-review
Source:         https://files.pythonhosted.org/packages/source/g/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
# Note that this package is intentionally not using singlespec because
# it is not a library but a plain CLI tool, and it doesn't make sense to
# build a python2.x version of it anymore in 2019.
BuildRequires:  python-rpm-macros
BuildRequires:  python3-fixtures >= 0.3.14
BuildRequires:  python3-pbr
BuildRequires:  python3-pip
BuildRequires:  python3-requests >= 1.1
BuildRequires:  python3-stestr
BuildRequires:  python3-wheel
Requires:       python3-requests >= 1.1
Provides:       python3-git-review = %{version}
Obsoletes:      python3-git-review < %{version}
BuildArch:      noarch

%description
A git command for submitting branches to Gerrit

git-review is a tool that helps submitting git branches to gerrit for
review.

%prep
%autosetup -p1 -n git-review-%{version}

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
%fdupes %{buildroot}%{python3_sitelib}

%check
# Can't be executed because it fetches java from web and launches own gerrit
# instance to test against
#%%{python_expand $python -m git_review.tests.check_test_id_hashes discover --list
#$python -m git_review.tests.prepare
#$python setup.py testr}

%files
%license LICENSE
%doc AUTHORS README.rst
%{python3_sitelib}/git_review
%{python3_sitelib}/git_review-%{version}*-info
%{_bindir}/git-review
%{_mandir}/man1/git-review.1%{?ext_man}

%changelog
* Mon May 22 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Improved version string parsing for Git
* Tue Apr 19 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.3.0:
  * Python 3.5 is no longer supported.
  * Git 2.10.0 or later is required as git-review now needs the
  - -no-show-signature option for git-log.
  * Git’s log.ShowSignature option is now supported. Previously, setting it
    would confuse git-review into thinking there were twice as many changes
    to push.
  * OpenSSH has deprecated its use of scp/rcp protocol in favor of SFTP,
    which the embedded Apache mina-sshd in widely-deployed Gerrit versions
    does not yet support. Now git-review will attempt to detect whether
    scp’s -O option is available to force use of the legacy scp/rcp protocol,
    and apply it if so. Future git-review versions may change the fallback
    behavior once an SFTP subsystem is implemented and available for a new
    Gerrit release.
- Remove now unneeded BuildRequires on mock.
* Tue Dec  7 2021 Matej Cepl <mcepl@suse.com>
- Update to 2.2.0:
  - When checking for unstaged or uncommitted changes to avoid
    performing a test rebase, unstaged and uncommitted changes in
    Git submodules are now ignored since those won’t be rebased
    anyway.
  - git-review now handles the Git core.hooksPath configuration
    option correctly. Thus, it installs the commit-msg hook
    into the core.hooksPath directory, if that option is
    set. Otherwise, it continues to install the hook into
    .git/hooks, relative to the root of the checkout.
  - With Git 2.18.0 and later, the --rebase-merges (-r) option
    will be used in place of the deprecated --preserve-merges
    (-p) option. This fixes a critical error when git-review is
    used with Git versions 2.34.0 onward, where the old option is
    no longer available.
- Remove unnecessary
  7182166ec00ad3645821435d72c5424b4629165f.patch
* Sun Dec  5 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Add support for –no-thin which is passed to git push
  * A new gitreview.branchauthor option allows configuring the change author
    (owner) name part of the autocreated branch name when downloading changes.
  * A new gitreview.notopic configuration setting makes git-review always
    behave as if the --notopic command line option was supplied.
  * Added the --notify option, which can be used to ensure specified receivers
    receives email notifications
  * The Change-Id generating commit hook is now installed into any detected Git
    submodules, so that it will take effect when creating changes within a
    submodule and not just in the parent repository.
  * Encoding was corrected for Git credentials, which was previously causing HTTP
    authentication to fail under some Python 3 versions.
  * Change download functions now preserve any unapplied local edits on the
    branch when attempting to reset the worktree.
  * The --no-follow-tags option to git push is now used for all pushes, so that
    git-review won’t error when encountering a local tag which is absent from
    Gerrit.
  * For safety, attempts to push a commit with unstaged or uncommitted changes in
    the worktree will be caught and an error reported, rather than leaving it up to
    git rebase to spot them. This addresses a situation where users enabling
    rebase.autostash would otherwise experience data loss when the test rebase is
    subsequently reset.
- add 7182166ec00ad3645821435d72c5424b4629165f.patch:
  * With Git 2.18.0 and later, the --rebase-merges (-r) option will be used in
    place of the deprecated --preserve-merges (-p) option. This fixes a
    critical error when git-review is used with Git versions 2.34.0 onward,
    where the old option is no longer available.
* Fri May  3 2019 Dirk Mueller <dmueller@suse.com>
- revert switch to singlespec. This is an insane complexification
  for no gain: git-review is a pure cli tool, not a module
  to import, and we never had a working python2- version anyway
  because all the tooling was excluded from packaging. So
  don't create packages that are unusable and deprecated.
* Fri May  3 2019 Dirk Mueller <dmueller@suse.com>
- update to 1.28.0 (bsc#1134089):
  * Support for auto-configuration of topic names based on the
  presence of keywords in the commit message is removed. Previously,
  keywords such as bug, bp or lp followed by a number would result
  in branch names containing the associated number, e.g. bug/123.
  This feature was OpenStack specific, was a frequent source of bugs
  and clearly wasn’t being used that often, given that StoryBoard
  is a thing now and no one had updated this feature to handle that metadata.
  * Fixed usepushurl to work when a read-only mirror being used as origin does not contain refs/changes from gerrit.
* Tue Jan  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.27.0:
  * Work with python3
- Remove patch in upstream: git-2.15-compat.patch
- Switch to source url downloads
- Switch URL to point to active site
- Switch to singlespec
* Mon Nov 13 2017 dmueller@suse.com
- add git-2.15-compat.patch: fix compat with git 2.15
* Thu Aug 27 2015 tbechtold@suse.com
- Remove %%{_sysconfdir}/git-review/git-review.conf from package.
  File is deprecated.
* Sat Jun 13 2015 tbechtold@suse.com
- update to 1.25.0:
  * Add “git-review -l” to man page synopsis and usage doc
  * Add reviewers on upload
  * Update project links
  * Override E-mail in Gerrit integration tests
  * Fixed a dead link to the git-review docs
  * Provide an explanation on failed rebase
  * Switch to requests to support proxying of 'https'
  * Use plumbing rev-parse to get the branch name
  * Isolate tests from user/system git configuration
  * Push language override down into the cmd wrapper
  * git review -sv gets more verbose
  * Add utf-8 char support
  * Choose tracked branch for rebase when submitting
  * pbr should install the manpage
  * get_remote_url(): also honor url.*.pushInsteadOf
  * Support authentication in run_http_exc
  * Split README.rst into separate doc files
  * Handle correctly http error raise in run_http_exc
  * Fix encoding header
  * Workflow documentation is now in infra-manual
  * Update tests to use Gerrit 2.9.2
  * Use 'no_proxy' env variable in addition to uppercase
  * Enable color support based on tty and config
  * get_remote_url(): honor any "url.<base>.insteadOf" config setting
  * Convert add_remote to use GitReviewExceptions
  * Prefer git-config over git-review config files
  * Isolate tests from user/system config
  * Switched documentation to point to storyboard
  * Fix ---list and "departement" typos in man page
  * Align git-review and python -m git_review.cmd behaviors
  * Define -T/--no-topic to disable review submit with topic
  * Work toward Python 3.4 support and testing
  * -F/--force-rebase has no effect if rebase is disabled by config
  * Remove useless constants
  * Improve windows support for git-review --setup
  * Fix groff warnings with manpage
  * Enabled hacking checks H305 and H307
  * Prevent long subjects in reviews causing spurious blank lines
  * added link to get-pip to readme
  * Disable ssh/scp password authentication during tests
  * Update tests to use Gerrit 2.8.6.1
  * Build universal wheels
* Mon Sep 22 2014 bwiedemann@suse.com
- Require python-setuptools to fix CLI
* Wed Jul 16 2014 bwiedemann@suse.com
- update to 1.24
  * Require python-requests
  * Update homepage on PyPI
  * Update requirements to OpenStack's recommendations
  * Update the README to mention dependencies
  * Ensure username is set for all tests
  * Provide nicer user message for missing remote ref
  * Fix a typo in HACKING.rst
  * Ignore newline in bp/bug search in commit message
  * Restrict tests SSH auth to only the provided key
  * Disable proxies for tests that clone over http
  * Keep track of gerrit.war and golden_site versions
  * Fix typo in manpage s/gireview/gitreview/
  * Correct git review -l over http(s)
* Fri Jul  4 2014 speilicke@suse.com
- Avoid source Url, we're packaging from git
* Thu May 22 2014 dmueller@suse.com
- update to 1.23.61:
  * Topic: do not use '(detached' when detached
  * Use gerrit 2.8.5 instead of gerrit 2.6.1 in tests
  * Allow to specify default scheme in .gitreview file
  * Correct test_remote to support branchs without upstream
  * Remove parsing of --help and variants from our code
  * Python2: fixed UnicodeEncodeError
  * Skip invalid unicode in commit messages
  * Git review assumes the wrong ssh default port
  * Add http(s) protocol support to fetch_review and list_reviews
  * git-review.1 manpage fix for groff warnings
  * Fix parsing of SCP-style URLs, as these are valid in Git itself
  * "git review --setup" failed in Chinese locale
  * Bump hacking version in requirements
  * Reduce testr concurrnecy to 2
  * Add http(s) protocol support to set_hooks_commit_msg
  * Retrieve remote pushurl independently of user's locale
  * Add http(s) protocol support to test_remote
  * Verify if every attached file exists. Attach gerrig.config
  * Wrap exceptions that occur while running external process
  * Make Gerrit port and dir selection deterministic
  * Don't try to attach known_hosts if it's not there
  * Remove tox locale overrides
  * Fix the regex for setting topic
  * Add 2m timeout to tests
  * Attach Gerrit logs and known_hosts to failed tests
  * Change test gerrit ssh/http ports offset
  * Correct .Fl typo WRT --compare in the manual page
  * Ignore content of merge commits in reporting
  * Remove empty lines from git log output
  * Preserve merges when doing a rebase
  * Split git rev-parse --show-toplevel --git-dir on newline
  * Prefer .gitconfig username
  * Add more deterministic port selection for Gerrit
  * Document source location as git.openstack.org
  * Implement integration tests
  * Migrate to pbr
  * No longer check for new git-review releases
- remove git-review-username.diff: merged upstream
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Sep 11 2013 aj@suse.com
- Add patch git-review-username.diff to prefer .gitconfig username
  (see https://review.openstack.org/46015)
- Update to version 1.23:
    Expand multiple commit submission warning.
* Mon Jun  3 2013 vmiklos@suse.com
- Update to version 1.22
- Changes from version 1.20:
  + Allows easy cherry-picking of a change
  + See https://github.com/openstack-infra/git-review/compare/1.20...1.22
* Wed Feb 27 2013 saschpe@suse.de
- Update to version 1.20:
  + Avoid symlinks in the manpage path
- Changes from version 1.19:
  + Allow download of reviews from deleted accounts
  + See https://github.com/openstack-infra/git-review/compare/1.18...1.19
- Renamed from python-git-review, it's a tool not a library
- Install man-page in correct location
- Explicit %%py_requires, since we don't have files in %%python_sitelib
* Thu Sep 20 2012 rhafer@suse.com
- Update to 1.18:
  * Adds Python3 support and various bugfixes
- Package a default configuration file to disable the automatic check
  for new git-review releasess on PyPI. Otherwise git-review refuses
  to work when a new release is available on PyPI
* Thu May 24 2012 saschpe@suse.de
- Initial version
